@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.116_06';
+our $VERSION = '0.117_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Fri Mar  8 15:56:42 2019 GMT
+# on Tue Mar 12 17:02:25 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1709,7 +1709,7 @@ __PACKAGE__->status( add => 24907, iridium => '-', 'Iridium 22', 'Tumbling' );
 __PACKAGE__->status( add => 24925, iridium => '-', 'Dummy mass 1', 'Tumbling' );
 __PACKAGE__->status( add => 24926, iridium => '-', 'Dummy mass 2', 'Tumbling' );
 __PACKAGE__->status( add => 24944, iridium => '-', 'Iridium 29', 'Tumbling' );
-__PACKAGE__->status( add => 24945, iridium => '-', 'Iridium 32', 'Tumbling' );
+__PACKAGE__->status( add => 24945, iridium => 'D', 'Iridium 32', 'Decayed 2019-03-10' );
 __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
@@ -1742,7 +1742,7 @@ __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
-__PACKAGE__->status( add => 25275, iridium => '-', 'Iridium 59', 'Tumbling' );
+__PACKAGE__->status( add => 25275, iridium => 'D', 'Iridium 59', 'Decayed 2019-03-11' );
 __PACKAGE__->status( add => 25276, iridium => '-', 'Iridium 60', 'Tumbling' );
 __PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 2
 #       Spare [S]: 6
-#    Tumbling [-]: 37
-#     Decayed [D]: 52
+#    Tumbling [-]: 35
+#     Decayed [D]: 54
 
 1;
 
